@@ -1,8 +1,9 @@
 #ifndef _DJPLAY_H_INCLUDED
 #define _DJPLAY_H_INCLUDED
 
-#define _(x) x
+#define _(x) gettext(x)
 
+#include <libintl.h>
 #include <qdialog.h>
 
 #ifdef __WIN__
