@@ -13,8 +13,8 @@
 #include "mainwnd-background-1.xpm"
 #include "mainwnd-background-2.xpm"
 #include "config.h"
-#include <bitmapbutton.h>
-#include <bitmapslider.h>
+#include "plugins/bitmapbutton/bitmapbutton.h" 
+#include "plugins/bitmapslider/bitmapslider.h" 
 #include "cfgfile.h"
 #include "metatracker.h"
 
@@ -718,13 +718,17 @@ void MainWnd::bend_timeout( void )
     
     if(bend < 0)
     {
-	bend+=1;
+	bend+=2;
+	if(bend > 0)
+		bend=0;
 	current_source->set_pitch(base_pitch+(double)bend/10);
 	return;
     }
     if(bend > 0)
     {
-	bend-=1;
+	bend-=2;
+	if(bend < 0)
+		bend=0;
 	current_source->set_pitch(base_pitch+(double)bend/10);
 	return;
     }
@@ -991,17 +995,16 @@ void MainWnd::loaderEvent(QLoaderEvent *e)
     delete e->loader();
 	if(current_source->can_do_multiple_reads())
 	{
-		StreamSource *bpm_source=current_source->get_source();
-		connect(bpm_source, SIGNAL(agc_change(double)), this, SLOT(agc_change(double)));
-		if(bpm_source->sample_rate >= 500 && config->getValue("AutoBPM", "1").toInt())
+		if(current_source->sample_rate >= 500 && ! config->getValue("AutoBPM", "1").toInt())
 		{
+			StreamSource *bpm_source=current_source->get_source();
+			connect(bpm_source, SIGNAL(agc_change(double)), this, SLOT(agc_change(double)));
 			bpm_detect=new BPMDetect(this, bpm_source);
 			bpm_detect->start();
 			s_bpm=-1.0f;
 		}
 		else
 		{
-			delete bpm_source;
 			s_bpm=0.0f;
 		}
 	}
