@@ -1,10 +1,10 @@
 class Mp3Map
 {
 public:
-	Mp3Map::Mp3Map();
-	Mp3Map::Mp3Map(int fd);
-	Mp3Map::Mp3Map(const char *path);
-	Mp3Map::~Mp3Map();
+	Mp3Map();
+	Mp3Map(int fd);
+	Mp3Map(const char *path);
+	~Mp3Map();
 
 	int offset_to_frame(unsigned long offset);
 	unsigned long frame_to_offset(int frame);
